//
// QPerforce is a gui interface to the perforce revision control
// system. It is based on the qt library, and should be easily portable
// across any platform that has this toolkit available.
// 
// Copyright (C) 2002 Jacob Gladish
// 
#include "ViewMenu.h"
#include "ConfigOptions.h"
#include "qperforceWindow.h"
#include "todo.h"

#include <qcheckbox.h>
#include <qmainwindow.h>
#include <qpixmap.h>
#include <qstatusbar.h>

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

ViewMenu::ViewMenu( QWidget* parent, const char* name ) :
  QPopupMenu( parent, name )
{
  setCheckable( true );

  QString pixmapDir = ConfigOptions::getInstance()->getImageDir();  

  _showBranchSpecId = insertItem( "BranchSpecs");
  setAccel( Key_F8, _showBranchSpecId );

  _changeLists = new QPopupMenu();
  CHECK_PTR( _changeLists );
  _changeLists->insertItem( "Pending Changelists", this, 
    SLOT(slotPendingChangelists()), Key_F6 );

  _showSubmittedChangeListsId = _changeLists->insertItem( 
    "Submitted Changelists", Key_F7 );

  insertItem( "ChangeLists", _changeLists );

  insertItem( "ClientSpecs", this, SLOT(slotClientSpecs()), Key_F10 );
  _showJobsId = insertItem( QPixmap(pixmapDir+"/job.png"), "Jobs" );
  setAccel( Key_F12, _showJobsId );

  insertItem( "Labels", this, SLOT(slotLabels()), Key_F9 );
 
  
  _usersId = insertItem( QPixmap(pixmapDir+"/people.png"), "Users" );
  setAccel( Key_F11, _usersId );

  insertSeparator();

  insertItem( "Client View of Depot", this, SLOT(slotClientViewOfDepot()) );
  insertItem( "Local View of Depot", this, SLOT(slotLocalViewOfDepot()) );
  insertItem( "Local View of Client Tree", this, SLOT(slotLocalViewOfClientTree()) );
  insertItem( "Entire Depot", this, SLOT(slotEntireDepot()) );  

  insertSeparator();

  insertItem( "Filter Depot...", this, SLOT(slotFilterDepot()) );
  insertItem( "Clear Filter", this, SLOT(slotClearFilter()) );

  insertSeparator();

 // _showToolBar = new QCheckBox( "Show Toolbar", this );
 //CHECK_PTR( _showToolBar );
 //_showToolBar->setChecked( true );
 //QObject::connect( _showToolBar, SIGNAL(toggled(bool)),
 //                   this,         SLOT(slotShowToolBar(bool)) );
 // insertItem( _showToolBar );
 //   
 // _showStatusBar = new QCheckBox( "Show Status Bar", this );
 // CHECK_PTR( _showStatusBar );
 // _showStatusBar->setChecked( true );  
 // QObject::connect( _showStatusBar, SIGNAL(toggled(bool)),
 //                   this,           SLOT(slotShowStatusBar(bool))  );
 // insertItem( _showStatusBar );

  
  _showToolBarId = insertItem( "Show Toolbar", this, 
    SLOT(slotShowToolBar()) ); 
  setItemChecked( _showToolBarId, true );

  _showStatusBarId = insertItem( "Show Status Bar", this, 
    SLOT(slotShowStatusBar()) );
  setItemChecked( _showStatusBarId, true );

  insertSeparator();

  _bookMarks = new QPopupMenu();
  CHECK_PTR( _bookMarks );
  _bookMarks->insertItem( "Add Bookmark", this, SLOT(slotAddBoomark()) );
  _bookMarks->insertItem( "Organize Bookmarks", this, 
    SLOT(slotOrganizeBookmarks()) );
  insertItem( "Bookmarks", _bookMarks, CTRL+Key_B );  
  
  insertItem( "View Warnings and Errors...", this, 
    SLOT(slotViewWarningsAndErrors()) );
  insertItem( "Refresh Active Pane", this, SLOT(slotRefreshActivePane()),
    CTRL+Key_F5 );
}

ViewMenu::~ViewMenu()
{
  delete _changeLists;
  _changeLists = NULL;

  delete _bookMarks;
  _bookMarks = NULL;  
}

void ViewMenu::slotClientSpecs()
{
  TODO();
}

void ViewMenu::slotPendingChangelists()
{
  TODO();
}

void ViewMenu::slotLabels()
{
  TODO();
}

void ViewMenu::slotClientViewOfDepot()
{
  TODO();
}

void ViewMenu::slotLocalViewOfDepot()
{
  TODO();
}

void ViewMenu::slotLocalViewOfClientTree()
{
  TODO();
}

void ViewMenu::slotEntireDepot()
{
  TODO();
}

void ViewMenu::slotFilterDepot()
{
  TODO();
} 

void ViewMenu::slotClearFilter()
{
  TODO();
}

void ViewMenu::slotShowToolBar()
{
  TODO();
}

void ViewMenu::slotShowStatusBar()
{  
  QMainWindow* win = qperforceWindow::getInstance();
  ASSERT( win != NULL );

  QStatusBar* statusBar = win->statusBar();
  ASSERT( statusBar != NULL );
  
  bool b = isItemChecked( _showStatusBarId );  
  setItemChecked( _showStatusBarId, !b );

  if (b) {    
    statusBar->hide();    
  } else {
    statusBar->show();
  }
}

void ViewMenu::slotAddBoomark()
{
  TODO();
}

void ViewMenu::slotOrganizeBookmarks()
{
  TODO();
}

void ViewMenu::slotViewWarningsAndErrors()
{
  TODO();
}

void ViewMenu::slotRefreshActivePane()
{
  TODO();
}
